@@ -758,7 +758,7 @@ class Parser:
             self.raise_error("Expected AS in CTE")
 
         self._match_l_paren()
-        expression = self._parse_select()
+        expression = self._parse_with()
         self._match_r_paren()
 
         return self.expression(
@@ -1151,7 +1151,7 @@ class Parser:
             return self.expression(exp.BitwiseNot, this=self._parse_unary())
         if self._match(TokenType.DASH):
             return self.expression(exp.Neg, this=self._parse_unary())
-        return self._parse_type()
+        return self._parse_at_time_zone(self._parse_type())
 
     def _parse_type(self):
         if self._match(TokenType.INTERVAL):
@@ -1231,6 +1231,12 @@ class Parser:
             nested=nested,
         )
 
+    def _parse_at_time_zone(self, this):
+        if not self._match(TokenType.AT_TIME_ZONE):
+            return this
+
+        return self.expression(exp.AtTimeZone, this=this, zone=self._parse_string())
+
     def _parse_column(self):
         this = self._parse_field()
         if isinstance(this, exp.Identifier):
